Cleaned up some of the host-related abstractions and filled in more of the host manager implementation.
diff --git a/core/api/src/main/java/org/onlab/onos/net/host/HostProviderService.java b/core/api/src/main/java/org/onlab/onos/net/host/HostProviderService.java
index 76c2aad..ed568e8 100644
--- a/core/api/src/main/java/org/onlab/onos/net/host/HostProviderService.java
+++ b/core/api/src/main/java/org/onlab/onos/net/host/HostProviderService.java
@@ -1,5 +1,6 @@
 package org.onlab.onos.net.host;
 
+import org.onlab.onos.net.HostId;
 import org.onlab.onos.net.provider.ProviderService;
 
 /**
@@ -11,15 +12,16 @@
      * Notifies the core when a host has been detected on a network along with
      * information that identifies the hoot location.
      *
+     * @param hostId          id of the host that been detected
      * @param hostDescription description of host and its location
      */
-    void hostDetected(HostDescription hostDescription);
+    void hostDetected(HostId hostId, HostDescription hostDescription);
 
     /**
      * Notifies the core when a host is no longer detected on a network.
      *
      * @param hostDescription description of host
      */
-    void hostVanished(HostDescription hostDescription);
+    void hostVanished(HostId hostId);
 
 }
@@ -11,15 +12,16 @@
      * Notifies the core when a host is no longer detected on a network.
      *
-     * @param hostDescription description of host
+     * @param hostId id of the host that vanished
      */